@@ -946,7 +946,7 @@ S_expected <- structure(c(0L, 1L, 2L, 3L, 4L, 5L, 0L, 1L, 2L, 3L, 4L, 5L, 0L,
                           3L, 4L, 5L, 0L, 1L, 2L, 3L, 4L, 5L, 0L, 1L, 2L, 3L,
                           4L, 5L, 0L, 1L, 2L, 3L, 4L, 5L),
                         .Dim = c(6L, 10L))
-S_observed <- trajectory(result, compartments = "S", as.is = TRUE)
+S_observed <- trajectory(result, compartments = "S", format = "matrix")
 stopifnot(identical(S_observed, S_expected))
 
 I_expected <- structure(c(0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L,
@@ -955,14 +955,15 @@ I_expected <- structure(c(0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L,
                           0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L,
                           0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L),
                         .Dim = c(6L, 10L))
-I_observed <- trajectory(result, compartments = "I", as.is = TRUE)
+I_observed <- trajectory(result, compartments = "I", format = "matrix")
 stopifnot(identical(I_observed, I_expected))
 
 ## Check output from trajectory method
 model@tspan <- c(1, 2)
 result <- run(model)
-res <- assertError(trajectory(result, c("S", "phi"), as.is = TRUE))
-check_error(res, "Select either continuous or discrete compartments.")
+res <- assertError(trajectory(result, c("S", "phi"), format = "matrix"))
+check_error(res,
+            "Cannot combine data from different slots.")
 
 stopifnot(identical(class(trajectory(result, c("S", "phi"))$phi), "numeric"))
 stopifnot(identical(class(trajectory(result, c("phi"))$phi), "numeric"))
@@ -995,27 +996,29 @@ traj_expected <- data.frame(
     S = c(1L, 4L, 1L, 4L),
     phi = c(0.1, 0.4, 0.1, 0.4))
 stopifnot(identical(
-    trajectory(result, c("S", "S", "phi", "phi"), node = c(5, 2))[, -4],
+    trajectory(result, c("S", "S", "phi", "phi"), index = c(5, 2))[, -4],
     traj_expected[, -4]))
 stopifnot(identical(
-    trajectory(result, c("phi", "phi", "S", "S"), node = c(5, 2))[, -4],
+    trajectory(result, c("phi", "phi", "S", "S"), index = c(5, 2))[, -4],
     traj_expected[, -4]))
 stopifnot(identical(
-    trajectory(result, c("S", "phi"), node = c(5, 2)),
+    trajectory(result, c("S", "phi"), index = c(5, 2)),
     traj_expected))
 
-d <- trajectory(result, c("phi", "phi", "S", "S"), node = c(5, 2))[, 4] -
+d <- trajectory(result, c("phi", "phi", "S", "S"), index = c(5, 2))[, 4] -
     traj_expected$phi
 stopifnot(all(abs(d) < 1e-8))
 
 ## Check extracting all compartments in U
-stopifnot(identical(trajectory(result, c("S", "I"), as.is = TRUE), result@U))
+stopifnot(identical(trajectory(result, c("S", "I"), format = "matrix"),
+                    result@U))
 
 ## Check extracting all compartments of U in internal format
-stopifnot(identical(trajectory(result, c("S", "I"), as.is = TRUE), result@U))
+stopifnot(identical(trajectory(result, c("S", "I"), format = "matrix"),
+                    result@U))
 
 ## Check extracting a subset compartments of V in internal format
-traj_observed <- trajectory(result, "phi", node = c(5, 2), as.is = TRUE)
+traj_observed <- trajectory(result, "phi", index = c(5, 2), format = "matrix")
 stopifnot(identical(dim(traj_observed), c(2L, 2L)))
 stopifnot(all(abs(traj_observed[1, ] - 0.1) < 1e-8))
 stopifnot(all(abs(traj_observed[2, ] - 0.4) < 1e-8))
@@ -1026,7 +1029,7 @@ traj_expected <- data.frame(node = c(2L, 5L, 2L, 5L),
                             S = c(1L, 4L, 1L, 4L),
                             I = c(0L, 0L, 0L, 0L))
 stopifnot(identical(
-    trajectory(result, c("S", "I"), node = c(5, 2)),
+    trajectory(result, c("S", "I"), index = c(5, 2)),
     traj_expected))
 
 ## Check extracting all compartments in U as a data.frame
